@@ -3,7 +3,6 @@
 # TRUSTBE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 #
 #
-from __future__ import annotations
 
 from enum import Enum
 
@@ -27,21 +26,21 @@ class MeshFlag(Enum):
         return self.value[1]
 
     @staticmethod
-    def of_proto(code: str) -> MeshFlag:
+    def of_proto(code: str) -> "MeshFlag":
         for member in MeshFlag:
             if member.value and member.value[0] == code:
                 return member
         return MeshFlag.HTTP
 
     @staticmethod
-    def of_code(code: str) -> MeshFlag:
+    def of_code(code: str) -> "MeshFlag":
         for member in MeshFlag:
             if member.value and member.value[0] == code:
                 return member
         return MeshFlag.JSON
 
     @staticmethod
-    def of_name(name: str) -> MeshFlag:
+    def of_name(name: str) -> "MeshFlag":
         for member in MeshFlag:
             if member.value and member.value[1] == name:
                 return member
