@@ -7,6 +7,7 @@ from mesh.macro.ark import ark, T, A, B, C
 from mesh.macro.binding import binding, Binding
 from mesh.macro.cause import Cause
 from mesh.macro.codec import serializable
+from mesh.macro.compatible import Compatible
 from mesh.macro.index import index, Index
 from mesh.macro.inspect import Returns, Parameters, Inspector
 from mesh.macro.loader import ServiceLoader
@@ -40,7 +41,9 @@ __all__ = ("mpi",
            "Returns",
            "Parameters",
            "Inspector",
-           "MethodProxy",)
+           "MethodProxy",
+           "Compatible",
+           )
 
 
 def init():
