@@ -24,7 +24,7 @@ class ServiceProxy(MethodProxy):
     @staticmethod
     def static_proxy(kind: Type[T], metadata: mpi) -> T:
         interface = kind
-        if hasattr(kind, "__args__"):
+        if hasattr(kind, "__args__") and getattr(kind, "__args__") is not None:
             interface = kind.__args__[0]
 
         if not inspect.isabstract(interface):
